Module error

Module error 

Helpers for dealing with errno.

Most errors in pros-rs are created by reading the last value of ERRNO. This includes the very generic PortError, which is used for most hardware that gets plugged into a port on a V5 Brain.

Most of the contents of this file are not public.

Enums

PortError
Generic erros that can take place when using ports on the V5 Brain.

Traits

FromErrno
A trait for converting an errno value into an error type.

Functions

take_errno
Gets the value of errno and sets errno to 0.

Type Aliases

Result
A result type that makes returning errors easier.