pub struct Mutex<T> { /* private fields */ }Expand description
The basic mutex type. Mutexes are used to share variables between tasks safely.
Implementations
Sourceimpl<T> Mutex<T>
impl<T> Mutex<T>
Sourcepub fn lock(&self) -> MutexGuard<'_, T>
pub fn lock(&self) -> MutexGuard<'_, T>
Locks the mutex so that it cannot be locked in another task at the same time. Blocks the current task until the lock is acquired.
Sourcepub fn try_lock(&self) -> Option<MutexGuard<'_, T>>
pub fn try_lock(&self) -> Option<MutexGuard<'_, T>>
Attempts to acquire this lock. This function does not block.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the mutex and returns the inner data.